

Move declarations to vt_kern.h

Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/char/vc_screen.c |    8 --------
 25-akpm/drivers/char/vt.c        |    1 -
 25-akpm/include/linux/vt_kern.h  |    9 +++++++++
 3 files changed, 9 insertions(+), 9 deletions(-)

diff -puN include/linux/vt_kern.h~vc-locking-tweaks include/linux/vt_kern.h
--- 25/include/linux/vt_kern.h~vc-locking-tweaks	Fri Jun 25 14:23:22 2004
+++ 25-akpm/include/linux/vt_kern.h	Fri Jun 25 14:25:01 2004
@@ -11,6 +11,7 @@
 #include <linux/kd.h>
 #include <linux/tty.h>
 #include <linux/console_struct.h>
+#include <linux/mm.h>
 
 /*
  * Presently, a lot of graphics programs do not restore the contents of
@@ -84,4 +85,12 @@ int vt_waitactive(int vt);
 void change_console(unsigned int);
 void reset_vc(unsigned int new_console);
 
+/*
+ * vc_screen.c shares this temporary buffer with the console write code so that
+ * we can easily avoid touching user space while holding the console spinlock.
+ */
+extern char con_buf[PAGE_SIZE];
+#define CON_BUF_SIZE	PAGE_SIZE
+extern struct semaphore con_buf_sem;
+
 #endif /* _VT_KERN_H */
diff -puN drivers/char/vc_screen.c~vc-locking-tweaks drivers/char/vc_screen.c
--- 25/drivers/char/vc_screen.c~vc-locking-tweaks	Fri Jun 25 14:23:22 2004
+++ 25-akpm/drivers/char/vc_screen.c	Fri Jun 25 14:23:45 2004
@@ -66,14 +66,6 @@ vcs_size(struct inode *inode)
 	return size;
 }
 
-/* We share this temporary buffer with the console write code
- * so that we can easily avoid touching user space while holding the
- * console spinlock.
- */
-extern char con_buf[PAGE_SIZE];
-#define CON_BUF_SIZE	PAGE_SIZE
-extern struct semaphore con_buf_sem;
-
 static loff_t vcs_lseek(struct file *file, loff_t offset, int orig)
 {
 	int size;
diff -puN drivers/char/vt.c~vc-locking-tweaks drivers/char/vt.c
--- 25/drivers/char/vt.c~vc-locking-tweaks	Fri Jun 25 14:23:22 2004
+++ 25-akpm/drivers/char/vt.c	Fri Jun 25 14:25:18 2004
@@ -1865,7 +1865,6 @@ static void do_con_trol(struct tty_struc
  * kernel memory allocation is available.
  */
 char con_buf[PAGE_SIZE];
-#define CON_BUF_SIZE	PAGE_SIZE
 DECLARE_MUTEX(con_buf_sem);
 
 /* acquires console_sem */
_
